@@ -3,12 +3,14 @@
 
 **Federated Learning** allows several sources (*nodes*) of data to contribute to a single model without sharing their
 data between them. It thus answers the problematic of data confidentiality. All federated learning algorithm follow
-those steps:\n
+those steps:
+
   1. Choosing a model to train\n
   2. Having each node training its own model\n
   3. Aggregate the models into a single one and share it with the nodes\n
   4. Nodes produce a new model taking the central model into account for their next learning phase. In addition, in IFRA
   the node will also produce a new model if its data is uptdated.\n
+
 Steps 2 to 4 are an 'iteration' of the learning and are repeated until either the user stops the algorithm or some
 threshold is reached. In IFRA, no thresholds exist, and the learning stops when the user(s) decide so.
 
@@ -17,6 +19,7 @@ Differential privacy is automatically applied in each node by slightly changing
 
 IFRA consists of 3 independent and asynchronous actors, represented by the abstract class `ifra.actor.Actor`.
 Each can be run individually and monitors changes in its inputs. The three actors are :
+
   * Nodes (**inputs**: data, central model, **output**: node model) (`ifra.node.Node`)
   * Aggregator (**input**: node models, **output**: aggregated model) (`ifra.aggregator.Aggregator`)
   * Central Server (**input**: aggregated model, **output**: central model) (`ifra.central_server.CentralServer`)
@@ -30,23 +33,35 @@ the aggregator does not have access to any information about the node. It does n
 
 In IFRA, one node produces one ruleskit.RuleSet object. Each user is free to define its own model by
 overloading the `ifra.fitters.Fitter` class, as long as it produces a ruleskit.RuleSet object.
-The available models currently are:\n
+The available models currently are:
+
   * decisiontreeregression (see `ifra.fitters.DecisionTreeRegressionFitter` for details)\n
-  * decisiontreeclassification (see `ifra.fitters.DecisionTreeClassificationFitter` for details)\n
+  * decisiontreeclassification (see `ifra.fitters.DecisionTreeClassificationFitter` for details)
+
 The user also has the liberty to define its own aggregation method, by overloading `ifra.aggregation.Aggregation`.
-The available aggregation methods currently are:\n
+The available aggregation methods currently are:
+
   * adaboost (see `ifra.aggregations.AdaBoostAggregation` for details)\n
+  * reverseadaboost (see `ifra.aggregations.ReverseAdaBoostAggregation` for details)\n
+  * keepall (see `ifra.aggregations.AggregateAll`)
+
 The user can implement the update method to be used by the node to take the central model into account by overloading
-the `ifra.node_model_updaters.NodeModelUpdater`. The available node updaters currently are:\n
-  * adaboost (see `ifra.node_model_updaters.AdaBoostNodeModelUpdater`)\n
+the `ifra.node_model_updaters.NodeModelUpdater`. The available node updaters currently are:
+
+  * adaboost (adapted for adaboost, reverseadaboost and keepall aggregations)
+  (see `ifra.node_model_updaters.AdaBoostNodeModelUpdater`)
+
 Each node has the possbility to execute a dataprep before the first learning. The user has the liberty to define its
-dataprep method by overloading the `ifra.datapreps.DataPrep` class. The available datapreps currently are:\n
-  * binfeatures (see `ifra.datapreps.BinFeaturesDataPrep`)\n
+dataprep method by overloading the `ifra.datapreps.DataPrep` class. The available datapreps currently are:
+
+  * binfeatures (see `ifra.datapreps.BinFeaturesDataPrep`)
 
 To overload a class, read its documentation. Then, to make the actors use your class specify them in the
 actor's configuration file (`ifra.config.NodeLearningConfig` for *fitter*, *node updater* and *dataprep*) or in
 `ifra.config.AggregatorConfig` json file for *aggregation*).
+
 To be correctly imported, the line passed in the json for, let's say, the aggregation, must be like
+
 >>> {
 >>>    ...
 >>>    "aggregation": "some.importable.AggregationClass"
@@ -57,6 +72,7 @@ where *some.importable.AggregationClass* can be imported from the current workin
 To preserve data separation, each actor should be ran on a different machine. Models are shared across actors through
 Google Cloud Storage, and it is the reponsability of the user to define buckets to store the models the the appropriate
 I/O rights for each actors.
+
   * Each node should have read access the one unique bucket where the central model is to be written. In addition, each
     node should have a read access its own data. No other actor should have read access to them. It should also have
     write access to a place where the nodes models will be written. The place must be identical for each node of a
@@ -69,7 +85,8 @@ I/O rights for each actors.
 GCS paths are handeled by transparentpath.TransparentPath objects. For testing purposes, those paths can be local if no
 global filesystem is set by transparentpath.TransparentPath.
 
-To use IFRA, you need to do 5 things:\n
+To use IFRA, you need to do 5 things:
+
   1. Define the nodes learning configurations in json files. It should be stored on GCS with read access by the node
      only (set the appropriate access to the service accounts). See `ifra.configs.NodeLearningConfig` for more
      information.\n
@@ -89,7 +106,8 @@ To use IFRA, you need to do 5 things:\n
 
 Step 5, 6 and 7 can be done in any order.
 
-Example of step 1: you could create nodes learning configuration json files contaning:
+Example of step 1: you could create nodes learning configuration json files contaning.
+
 >>> {
 >>>     "features_names": ["sepal length in cm", "sepal width in cm", "petal length in cm", "petal width in cm"],
 >>>     "classes_names": ["Iris-setosa", "Iris-versicolor", "Iris-virginica"],  # Use an empty list if using regression
@@ -122,6 +140,7 @@ See `ifra.configs.NodeLearningConfig` for information about those configurations
 
 
 Example of step 2: you could create nodes data configuration json files contaning:
+
 >>> {
 >>>   "x_path": "gs://bucket_node_0/x.csv",
 >>>   "y_path": "gs://bucket_node_0/y.csv",
@@ -134,6 +153,7 @@ Example of step 2: you could create nodes data configuration json files contanin
 See `ifra.configs.NodeDataConfig` for information about those configurations.
 
 Example of step 3: you could create a aggragator configuration json file contaning:
+
 >>> {
 >>>     "node_models_path": "gs://bucket_node_models",
 >>>     "node_models_path_fs": "gcs",
@@ -151,6 +171,7 @@ Example of step 3: you could create a aggragator configuration json file contani
 See `ifra.configs.AggretatorConfig` for information about those configurations.
 
 Example of step 4: you could create a central server configuration json file contaning:
+
 >>> {
 >>>     "central_model_path": "gs://bucket_central_model/ruleset.csv",
 >>>     "central_model_path_fs": "gcs",
@@ -163,6 +184,7 @@ Example of step 4: you could create a central server configuration json file con
 See `ifra.configs.CentralConfig` for information about those configurations.
 
 Example of step 5:
+
 >>> from ifra import Node, NodeLearningConfig, NodeDataConfig
 >>> from transparentpath import Path
 >>> learning_config_path = NodeLearningConfig(Path("gs://bucket_node_learning_configs/learning_configs_0.json"))
@@ -171,6 +193,7 @@ Example of step 5:
 >>> thenode.run()
 
 Example of step 6:
+
 >>> from ifra import Aggregator, NodeLearningConfig, AggregatorConfig
 >>> nodes_learning_config = [
 >>>   NodeLearningConfig(Path("gs://bucket_node_learning_configs/learning_configs_0.json"))
@@ -183,6 +206,7 @@ Example of step 6:
 >>> aggr.run()
 
 Example of step 7:
+
 >>> from ifra import CentralServer, CentralConfig
 >>> central_config = CentralConfig(Path("central_configs.json", fs="local"))
 >>> server = CentralServer(central_configs=central_config)
